package cn.iocoder.yudao.module.order.service.order;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderConsignee.OrderConsigneeDO;
import cn.iocoder.yudao.module.order.vo.orderConsignee.OrderConsigneeCreateReqVO;
import cn.iocoder.yudao.module.order.vo.orderConsignee.OrderConsigneeQueryVO;
import cn.iocoder.yudao.module.order.vo.orderConsignee.OrderConsigneeUpdateReqVO;
import org.springframework.scheduling.annotation.Async;

import javax.validation.Valid;
import java.util.Collection;
import java.util.List;

/**
 * 订单收货人信息 Service 接口
 *
 * @author 系统管理员
 */
public interface OrderConsigneeService extends IService<OrderConsigneeDO> {

    /**
     * 创建订单收货人信息
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createOrderConsignee(@Valid OrderConsigneeCreateReqVO createReqVO);

    /**
     * 更新订单收货人信息
     *
     * @param updateReqVO 更新信息
     */
    void updateOrderConsignee(@Valid OrderConsigneeUpdateReqVO updateReqVO);

    /**
     * 删除订单收货人信息
     *
     * @param id 编号
     */
    void deleteOrderConsignee(Long id);

    /**
     * 获得订单收货人信息
     *
     * @param id 编号
     * @return 订单收货人信息
     */
    OrderConsigneeDO getOrderConsignee(Long id);

    /**
     * 获得订单收货人信息
     *
     * @param orderId 订单编号
     * @return 订单收货人信息
     */
    OrderConsigneeDO getOrderConsigneeByOrderId(Long orderId);

    /**
     * 获得订单收货人信息列表
     *
     * @param ids 编号
     * @return 订单收货人信息列表
     */
    List<OrderConsigneeDO> getOrderConsigneeList(Collection<Long> ids);

    /**
     * 获得订单收货人信息分页
     *
     * @param page  分页查询
     * @param query 查询
     * @return 订单收货人信息分页
     */
    PageResult<OrderConsigneeDO> getOrderConsigneePage(OrderConsigneeQueryVO query, PageVO page);

    /**
     * 获得订单收货人信息列表, 用于 Excel 导出
     *
     * @param query 查询
     * @return 订单收货人信息列表
     */
    List<OrderConsigneeDO> getOrderConsigneeList(OrderConsigneeQueryVO query);

}
